@@ -126,6 +126,9 @@ containing array references.
 
 Return column names as an array reference.
 
+  # Names of all columns
+  say for @{$results->columns};
+
 =head2 expand
 
   $results = $results->expand;
@@ -187,6 +190,6 @@ L<Mojo::Util/"tablify">.
 
 =head1 SEE ALSO
 
-L<Mojo::Pg>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
+L<Mojo::Pg>, L<Mojolicious::Guides>, L<http://mojolicious.org>.
 
 =cut
